NLSL: pltx_dummy.c Source File

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

pltx_dummy.c
Go to the documentation of this file.
1 /* dummy function to stand in for pltx functions and allow compilation on windows
2 */
3
4 /* Structure definitions */
5
6 #include <stdio.h>
7 #include <stdlib.h>
8 #include <string.h>
9 #include "fortrancall.h"
10
11 #define MAX_WINDOWS 5
12
13 typedef char word[20]; /* Defined sting type word */
14
15 /* Global variable declarations */
16 int numwndws = 0; /* Initialize number of windows to 0 */
17 int done = 0; /* Initialize "done" to "not done" */
18 int displayOK = 0; /* Variable to keep wpoll from attempting to
19 check events for nonexistant windows */
20
21 /********************************/
22 void FORTRAN (getwndws) (int *n, word * title)
23 { /* Begin getwndws */
24 /* declarations */
25 //printf("Received a call to getwndws(%d,%s)",n,title);
26 } /* End getwndws */
27
28 /********************************/
29 void FORTRAN (fstplt) (double *y1, double *y2, double *xmin1,
30 double *xstep1, int *indx1, int *wnum)
31 /* double *y1, *y2; y1 is the experimental, y2 is the
32 double *xmin1, *xstep1; difference (experimental-simulated)
33 int *indx1, *wnum; */
34 { /* Begin fstplt */
35 /* declarations */
36 //printf("received a call to fstplt(%g,%g,%g,%g,%d,%d)",y1,y2,xmin1,xstep1,indx1,wnum);
37 } /* End fstplt */
38
39 /********************************/
40 void FORTRAN (wpoll) ()
41 { /* Begin wpoll */
42 //printf("received a call to wpoll");
43 } /* End wpoll */
44
45 /********************************/
46 void FORTRAN (shtwndws) ()
47 { /* Begin shtwndws */
48 //printf("Received a call to shtwndws");
49 } /* End shtwndws */
50
51 /********************************/
fstplt
void FORTRAN() fstplt(double *y1, double *y2, double *xmin1, double *xstep1, int *indx1, int *wnum)
Definition: pltx_dummy.c:29
wpoll
void FORTRAN() wpoll()
Definition: pltx_dummy.c:40
done
int done
Definition: pltx_dummy.c:17
FORTRAN
#define FORTRAN(n)
Definition: fortrancall.h:8
numwndws
int numwndws
Definition: pltx_dummy.c:16
word
char word[20]
Definition: pltx_dummy.c:13
fortrancall.h
getwndws
void FORTRAN() getwndws(int *n, word *title)
Definition: pltx_dummy.c:22
shtwndws
void FORTRAN() shtwndws()
Definition: pltx_dummy.c:46
displayOK
int displayOK
Definition: pltx_dummy.c:18